@@ -5,7 +5,7 @@
 # This file is exec'ed in setup.py, don't import anything!
 
 # Same semantics as sys.version_info.
-version_info = (4, 0, 3, 'final', 0)
+version_info = (4, 3, 4, 'final', 0)
 
 
 def _make_version(major, minor, micro, releaselevel, serial):
@@ -22,7 +22,7 @@ def _make_version(major, minor, micro, releaselevel, serial):
 
 def _make_url(major, minor, micro, releaselevel, serial):
     """Make the URL people should start at for this version of coverage.py."""
-    url = "https://coverage.readthedocs.org"
+    url = "https://coverage.readthedocs.io"
     if releaselevel != 'final':
         # For pre-releases, use a version-specific URL.
         url += "/en/coverage-" + _make_version(major, minor, micro, releaselevel, serial)
